# HomePage Slides Refactoring

This change refactors the slides on the HomePage to use a StreamField instead of individual fields for each slide. This makes the slides more flexible and allows for an arbitrary number of slides.

## Changes Made

1. Added a new `slides` StreamField to the HomePage model
2. Updated the HomePage content panels to include the new StreamField
3. Updated the home_page.html template to render the new StreamField slides
4. Created a migration for the changes to the HomePage model

## Data Migration

The existing slide fields are still available for backward compatibility, but they are marked as deprecated. The template will first check for the new StreamField slides, and fall back to the legacy fields if the StreamField is empty.

A data migration has been integrated into the Django migration system to automatically transfer existing data from the legacy slide fields to the new StreamField. When you run the migrations, the system will:

1. Add the new `slides` StreamField to the HomePage model
2. Automatically migrate any existing data from the legacy slide fields to the new StreamField
3. Preserve the legacy fields for backward compatibility

This means you don't need to manually migrate the data - it's handled automatically by the migration system.

After confirming that all data has been successfully migrated and that the new StreamField is working correctly in production, you can remove the legacy fields from the HomePage model in a future update.
